@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0302';
+our $VERSION = '0.0303';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -166,18 +166,17 @@ sub generate {
     $chosen[0] = $fixed[0] if $self->tonic;
 
     # Intersect with the next-chord pitches
-    my @intersect;
     if ($next_chord) {
         my $A1 = Set::Array->new(@fixed);
         my $A2 = Set::Array->new(@next_pitches);
-        @intersect = @{ $A1->intersection($A2) };
+        my @intersect = @{ $A1->intersection($A2) };
         # DEBUGGING:
         if ($self->verbose) {
             my @named = map { Music::Note->new($_, 'midinum')->format('ISO') } @intersect;
             print "\tINTERSECT: ",ddc(\@named);
         }
         # Lead to the next chord
-        $chosen[-1] = $intersect[int rand @intersect];
+        $chosen[-1] = $intersect[int rand @intersect] if @intersect;
     }
 
     # Show them what they've won, Bob!
@@ -203,7 +202,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0302
+version 0.0303
 
 =head1 SYNOPSIS
 
